/v1/virtualbox/{uuid}/resume — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/virtualbox/{uuid}/resume

Contents

- /v1/virtualbox/{uuid}/resume
  - POST /v1/virtualbox/{uuid}/resume
    - Parameters
    - Response status codes

## POST /v1/virtualbox/{uuid}/resume

Resume a suspended VirtualBox VM instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 400: Invalid instance UUID
- 404: Instance doesn’t exist
- 204: Instance resumed

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »